package envoy.client.ui.listcell;

import javafx.geometry.Pos;
import javafx.scene.control.Label;
import javafx.scene.layout.*;

import envoy.data.Contact;
import envoy.data.Group;
import envoy.data.User;

/**
 * This class formats a single {@link Contact} into a UI component.
 * <p>
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>ContactControl.java</strong><br>
 * Created: <strong>01.07.2020</strong><br>
 *
 * @author Leon Hofmeister
 * @since Envoy Client v0.1-beta
 */
public class ChatControl extends HBox {

	/**
	 * @param contact the contact that should be formatted
	 * @since Envoy Client v0.1-beta
	 */
	public ChatControl(Contact contact, int unreadMessagesAmount) {
		// Container with contact name
		final var	vBox		= new VBox();
		final var nameLabel = new Label(contact.getName());
		nameLabel.setWrapText(true);
		vBox.getChildren().add(nameLabel);
		if (contact instanceof User) {
			// Online status
			final var	user		= (User) contact;
			final var	statusLabel	= new Label(user.getStatus().toString());
			statusLabel.getStyleClass().add(user.getStatus().toString().toLowerCase());
			vBox.getChildren().add(statusLabel);
		} else // Member count
			vBox.getChildren().add(new Label(((Group) contact).getContacts().size() + " members"));
				
		getChildren().add(vBox);
		if (unreadMessagesAmount != 0) {
			Region spacing = new Region();
			setHgrow(spacing, Priority.ALWAYS);
			getChildren().add(spacing);
			final var unreadMessagesLabel = new Label("" + unreadMessagesAmount);
			unreadMessagesLabel.setMinSize(15, 15);
			var vBox2 = new VBox();
			vBox2.setAlignment(Pos.CENTER_RIGHT);
			unreadMessagesLabel.setAlignment(Pos.CENTER);
			unreadMessagesLabel.getStyleClass().add("unreadMessagesAmount");
			vBox2.getChildren().add(unreadMessagesLabel);
			getChildren().add(vBox2);
		}
	}
}
